ESTIMATOR_STATUS_DATA

Struct ESTIMATOR_STATUS_DATA 

pub struct ESTIMATOR_STATUS_DATA {
    pub time_usec: u64,
    pub vel_ratio: f32,
    pub pos_horiz_ratio: f32,
    pub pos_vert_ratio: f32,
    pub mag_ratio: f32,
    pub hagl_ratio: f32,
    pub tas_ratio: f32,
    pub pos_horiz_accuracy: f32,
    pub pos_vert_accuracy: f32,
    pub flags: EstimatorStatusFlags,
}
Available on crate feature dialect-avssuas only.
Estimator status message including flags, innovation test ratios and estimated accuracies. The flags message is an integer bitmask containing information on which EKF outputs are valid. See the ESTIMATOR_STATUS_FLAGS enum definition for further information. The innovation test ratios show the magnitude of the sensor innovation divided by the innovation check threshold. Under normal operation the innovation test ratios should be below 0.5 with occasional values up to 1.0. Values greater than 1.0 should be rare under normal operation and indicate that a measurement has been rejected by the filter. The user should be notified if an innovation test ratio greater than 1.0 is recorded. Notifications for values in the range between 0.5 and 1.0 should be optional and controllable by the user.

ID: 230

Fields

time_usec: u64

Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.

vel_ratio: f32

Velocity innovation test ratio

pos_horiz_ratio: f32

Horizontal position innovation test ratio

pos_vert_ratio: f32

Vertical position innovation test ratio

mag_ratio: f32

Magnetometer innovation test ratio

hagl_ratio: f32

Height above terrain innovation test ratio

tas_ratio: f32

True airspeed innovation test ratio

pos_horiz_accuracy: f32

Horizontal position 1-STD accuracy relative to the EKF local origin

pos_vert_accuracy: f32

Vertical position 1-STD accuracy relative to the EKF local origin

flags: EstimatorStatusFlags

Bitmap indicating which EKF outputs are valid.

Implementations

Source

impl ESTIMATOR_STATUS_DATA

pub const ENCODED_LEN: usize = 42usize

pub const DEFAULT: Self

pub fn random<R: RngCore>(rng: &mut R) -> Self

Available on crate feature arbitrary only.