pub struct GLOBAL_POSITION_INT_COV_DATA {
pub time_usec: u64,
pub lat: i32,
pub lon: i32,
pub alt: i32,
pub relative_alt: i32,
pub vx: f32,
pub vy: f32,
pub vz: f32,
pub covariance: [f32; 36],
pub estimator_type: MavEstimatorType,
}dialect-avssuas only.Expand description
The filtered global position (e.g. fused GPS and accelerometers). The position is in GPS-frame (right-handed, Z-up). It is designed as scaled integer message since the resolution of float is not sufficient. NOTE: This message is intended for onboard networks / companion computers and higher-bandwidth links and optimized for accuracy and completeness. Please use the GLOBAL_POSITION_INT message for a minimal subset.
ID: 63
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
lat: i32Latitude
lon: i32Longitude
alt: i32Altitude in meters above MSL
relative_alt: i32Altitude above ground
vx: f32Ground X Speed (Latitude)
vy: f32Ground Y Speed (Longitude)
vz: f32Ground Z Speed (Altitude)
covariance: [f32; 36]Row-major representation of a 6x6 position and velocity 6x6 cross-covariance matrix (states: lat, lon, alt, vx, vy, vz; first six entries are the first ROW, next six entries are the second row, etc.). If unknown, assign NaN value to first element in the array.
estimator_type: MavEstimatorTypeClass id of the estimator this estimate originated from.
Implementations