pub struct OPEN_DRONE_ID_SYSTEM_DATA {Show 15 fields
pub operator_latitude: i32,
pub operator_longitude: i32,
pub area_ceiling: f32,
pub area_floor: f32,
pub operator_altitude_geo: f32,
pub timestamp: u32,
pub area_count: u16,
pub area_radius: u16,
pub target_system: u8,
pub target_component: u8,
pub id_or_mac: [u8; 20],
pub operator_location_type: MavOdidOperatorLocationType,
pub classification_type: MavOdidClassificationType,
pub category_eu: MavOdidCategoryEu,
pub class_eu: MavOdidClassEu,
}dialect-avssuas only.Expand description
Data for filling the OpenDroneID System message. The System Message contains general system information including the operator location/altitude and possible aircraft group and/or category/class information.
ID: 12904
Fields
operator_latitude: i32Latitude of the operator. If unknown: 0 (both Lat/Lon).
operator_longitude: i32Longitude of the operator. If unknown: 0 (both Lat/Lon).
area_ceiling: f32Area Operations Ceiling relative to WGS84. If unknown: -1000 m. Used only for swarms/multiple UA.
area_floor: f32Area Operations Floor relative to WGS84. If unknown: -1000 m. Used only for swarms/multiple UA.
operator_altitude_geo: f32Geodetic altitude of the operator relative to WGS84. If unknown: -1000 m.
timestamp: u3232 bit Unix Timestamp in seconds since 00:00:00 01/01/2019.
area_count: u16Number of aircraft in the area, group or formation (default 1). Used only for swarms/multiple UA.
area_radius: u16Radius of the cylindrical area of the group or formation (default 0). Used only for swarms/multiple UA.
target_system: u8System ID (0 for broadcast).
target_component: u8Component ID (0 for broadcast).
id_or_mac: [u8; 20]Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.
operator_location_type: MavOdidOperatorLocationTypeSpecifies the operator location type.
classification_type: MavOdidClassificationTypeSpecifies the classification type of the UA.
category_eu: MavOdidCategoryEuWhen classification_type is MAV_ODID_CLASSIFICATION_TYPE_EU, specifies the category of the UA.
class_eu: MavOdidClassEuWhen classification_type is MAV_ODID_CLASSIFICATION_TYPE_EU, specifies the class of the UA.
Implementations