pub struct POSITION_TARGET_LOCAL_NED_DATA {}dialect-avssuas only.Expand description
Reports the current commanded vehicle position, velocity, and acceleration as specified by the autopilot. This should match the commands sent in SET_POSITION_TARGET_LOCAL_NED if the vehicle is being controlled this way.
ID: 85
Fields
time_boot_ms: u32Timestamp (time since system boot).
x: f32X Position in NED frame
y: f32Y Position in NED frame
z: f32Z Position in NED frame (note, altitude is negative in NED)
vx: f32X velocity in NED frame
vy: f32Y velocity in NED frame
vz: f32Z velocity in NED frame
afx: f32X acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
afy: f32Y acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
afz: f32Z acceleration or force (if bit 10 of type_mask is set) in NED frame in meter / s^2 or N
yaw: f32yaw setpoint
yaw_rate: f32yaw rate setpoint
type_mask: PositionTargetTypemaskBitmap to indicate which dimensions should be ignored by the vehicle.
coordinate_frame: MavFrameValid options are: MAV_FRAME_LOCAL_NED = 1, MAV_FRAME_LOCAL_OFFSET_NED = 7, MAV_FRAME_BODY_NED = 8, MAV_FRAME_BODY_OFFSET_NED = 9
Implementations