pub struct TUNNEL_DATA {
pub payload_type: MavTunnelPayloadType,
pub target_system: u8,
pub target_component: u8,
pub payload_length: u8,
pub payload: [u8; 128],
}dialect-avssuas only.Expand description
Message for transporting “arbitrary” variable-length data from one component to another (broadcast is not forbidden, but discouraged). The encoding of the data is usually extension specific, i.e. determined by the source, and is usually not documented as part of the MAVLink specification.
ID: 385
Fields
payload_type: MavTunnelPayloadTypeA code that identifies the content of the payload (0 for unknown, which is the default). If this code is less than 32768, it is a ‘registered’ payload type and the corresponding code should be added to the MAV_TUNNEL_PAYLOAD_TYPE enum. Software creators can register blocks of types as needed. Codes greater than 32767 are considered local experiments and should not be checked in to any widely distributed codebase.
target_system: u8System ID (can be 0 for broadcast, but this is discouraged)
target_component: u8Component ID (can be 0 for broadcast, but this is discouraged)
payload_length: u8Length of the data transported in payload
payload: [u8; 128]Variable length payload. The payload length is defined by payload_length. The entire content of this block is opaque unless you understand the encoding specified by payload_type.
Implementations